function diff_avg(study_dir, scan_id1, scan_id2, hscan_id, concM, Conc, save_dir)
%% COMA 3D Toolbox
%% Milton L. Truong 11-21-2013

%% Load Data sets
[data1, ~, param1] = loadimage(study_dir, scan_id1); % Sodium 1
[data2, ~, param2] = loadimage(study_dir, scan_id2); % Sodium 2
[hdata, ~, hparam] = loadimage(study_dir, hscan_id); % 1H

FOV = param1.acqp.ACQ_fov(1) * 10;
bFOV = hparam.acqp.ACQ_fov(1) * 10;

%%% Sodium Difference
diff3D = data2-data1;
Concmap = fconcmap(diff3D, concM, Conc);

%% Find Dimensions of each Array
[hrow, hcolumn, hslice] = size(hdata);
[drow, dcolumn, dslice] = size(Concmap);


%% Process arrays into X Y Z components
[Xdiff Ydiff Zdiff] = process(Concmap);
[X1 Y1 Z1] = process(hdata);

%Preallocating
diff30c = zeros(drow, dcolumn/2);
diff30cr = zeros(drow/2, dcolumn/2);

%% X
for g1 = 1:dslice
    diff = Xdiff(1,g1).slice;
    [mrow mcol] = size(diff);
    c=1;
    for col = 1:(mcol/2)
        diff30c(:,col) =(diff(:,c)+diff(:,c+1))/2;
        c=c+2;
    end

    r=1;
    for row = 1:(mrow/2)
        diff30cr(row,:) =(diff30c(r,:)+diff30c(r+1,:))/2;
        r=r+2;
    end
    Xavg(g1).slice = diff30cr;
end
lower = min(min([Xavg(:).slice]));
upper = max(max([Xavg(:).slice]));



for f = 1:hslice
    g=slicepick(f, hslice, dslice);
    mapoverlay(X1(1,f).slice, Xavg(1,g).slice, 0.1, lower, upper, 1, FOV);
    saveimage(save_dir,'X',f);
    close(gcf);
end

%% Y
for g1 = 1:dcolumn
    diff = Ydiff(1,g1).slice;
    [mrow mcol] = size(diff);
    c=1;
    for col = 1:(mcol/2)
        diff30c(:,col) =(diff(:,c)+diff(:,c+1))/2;
        c=c+2;
    end

    r=1;
    for row = 1:(mrow/2)
        diff30cr(row,:) =(diff30c(r,:)+diff30c(r+1,:))/2;
        r=r+2;
    end
    Yavg(g1).slice = diff30cr;
end
lower = min(min([Yavg(:).slice]));
upper = max(max([Yavg(:).slice]));


for f = 1:hcolumn
    g=slicepick(f, hcolumn, dcolumn);
    mapoverlay(Y1(1,f).slice, Yavg(1,g).slice, 0.1, lower, upper, 1, FOV);
    saveimage(save_dir,'Y',f);
    close(gcf);
end

%% Z
for g1 = 1:drow
    diff = Zdiff(1,g1).slice;
    [mrow mcol] = size(diff);
    c=1;
    for col = 1:(mcol/2)
        diff30c(:,col) =(diff(:,c)+diff(:,c+1))/2;
        c=c+2;
    end

    r=1;
    for row = 1:(mrow/2)
        diff30cr(row,:) =(diff30c(r,:)+diff30c(r+1,:))/2;
        r=r+2;
    end
    Zavg(g1).slice = diff30cr;
end
lower = min(min([Zavg(:).slice]));
upper = max(max([Zavg(:).slice]));


for f = 1:hrow
    g=slicepick(f, hrow, drow);
    mapoverlay(Z1(1,f).slice, Zavg(1,g).slice, 0.1, lower, upper, 1, FOV);
    saveimage(save_dir,'Z',f);
    close(gcf);
end

clearvars data1 data2 hdata X1 Y1 Z1 Xdiff Ydiff Zdiff Xavg Yavg Zavg;
end
        
    
    