function diff_full3D(study_dir, scan_id1, scan_id2, hscan_id, concM, Conc, save_dir)
%% COMA 3D Toolbox
%% Milton L. Truong 11-21-2013

%% Load Data sets
[data1, ~, param1] = loadimage(study_dir, scan_id1); % Sodium 1
[data2, ~, param2] = loadimage(study_dir, scan_id2); % Sodium 2
[hdata, ~, hparam] = loadimage(study_dir, hscan_id); % 1H

FOV = hparam.acqp.ACQ_fov(1) * 10;

%%% Sodium Difference
diff3D = data2-data1;
Concmap = fconcmap(diff3D, concM, Conc);

%% Find Dimensions of each Array
[hrow, hcolumn, hslice] = size(hdata);
[drow, dcolumn, dslice] = size(Concmap);

%% Process arrays into X Y Z components
[Xdiff Ydiff Zdiff] = process(Concmap);
[X1 Y1 Z1] = process(hdata);

%%% Preallocating
diff60c = zeros(dcolumn, drow);
diff60cr = zeros(dcolumn, drow);

%% X
a=1;
for col = 1:(dslice)
    if col < dcolumn
        avgX(1,col).slice = ((Xdiff(1,a).slice)+(Xdiff(1,a+1).slice))/2;
        a=a+1;
    else
        avgX(1,col).slice = ((Xdiff(1,a).slice)+(Xdiff(1,1).slice))/2;
    end    
end
[avgXslice, ~] = size(avgX(:));

for g1 = 1:dslice
    diff = avgX(1,g1).slice;
    [mrow mcol] = size(diff);
    c=1;
    for col = 1:mcol
        if col <mcol
        diff60c(:,col) =(diff(:,c)+diff(:,c+1))/2;
        c=c+1;
        else
            diff60c(:,col) =(diff(:,c)+diff(:,1))/2;
        end
            
    end

    r=1;
    for row = 1:mrow
        if row <mrow
        diff60cr(row,:) =(diff60c(r,:)+diff60c(r+1,:))/2;
        r=r+1;
        else
            diff60cr(row,:) =(diff60c(r,:)+diff60c(1,:))/2;
        end       
    end
    Xavg(g1).slice = diff60cr;
end
lower = min(min([Xavg(:).slice]));
upper = max(max([Xavg(:).slice]));

for f = 1:hslice
    g=slicepick(f, hslice, avgXslice);
    mapoverlay(X1(1,f).slice, Xavg(1,g).slice, 0.1, lower, upper, 1, FOV);
    saveimage(save_dir,'X',f);
    close(gcf);
end


%% Y
a=1;
for col = 1:(dcolumn)
    if col < dcolumn
        avgY(1,col).slice = ((Ydiff(1,a).slice)+(Ydiff(1,a+1).slice))/2;
        a=a+1;
    else
        avgY(1,col).slice = ((Ydiff(1,a).slice)+(Ydiff(1,1).slice))/2;
    end    
end

[avgYcolumn, ~] = size(avgY(:));

for g1 = 1:dcolumn
    diff = avgY(1,g1).slice;
    [mrow mcol] = size(diff);
    c=1;
    for col = 1:mcol
        if col <mcol
        diff60c(:,col) =(diff(:,c)+diff(:,c+1))/2;
        c=c+1;
        else
            diff60c(:,col) =(diff(:,c)+diff(:,1))/2;
        end
            
    end

    r=1;
    for row = 1:mrow
        if row <mrow
        diff60cr(row,:) =(diff60c(r,:)+diff60c(r+1,:))/2;
        r=r+1;
        else
            diff60cr(row,:) =(diff60c(r,:)+diff60c(1,:))/2;
        end       
    end
    Yavg(g1).slice = diff60cr;
end
lower = min(min([Yavg(:).slice]));
upper = max(max([Yavg(:).slice]));

for f = 1:hcolumn
    g=slicepick(f, hcolumn, avgYcolumn);
    mapoverlay(Y1(1,f).slice, Yavg(1,g).slice, 0.1, lower, upper, 1, FOV);
    saveimage(save_dir,'Y',f);
    close(gcf);
end


%% Z
a=1;
for col = 1:(drow)
    if col < dcolumn
        avgZ(1,col).slice = ((Zdiff(1,a).slice)+(Zdiff(1,a+1).slice))/2;
        a=a+1;
    else
        avgZ(1,col).slice = ((Zdiff(1,a).slice)+(Zdiff(1,1).slice))/2;
    end    
end

[avgZrow, ~] = size(avgZ(:));

for g1 = 1:drow
    diff = avgZ(1,g1).slice;
    [mrow mcol] = size(diff);
    c=1;
    for col = 1:mcol
        if col <mcol
        diff60c(:,col) =(diff(:,c)+diff(:,c+1))/2;
        c=c+1;
        else
            diff60c(:,col) =(diff(:,c)+diff(:,1))/2;
        end
            
    end

    r=1;
    for row = 1:mrow
        if row <mrow
        diff60cr(row,:) =(diff60c(r,:)+diff60c(r+1,:))/2;
        r=r+1;
        else
            diff60cr(row,:) =(diff60c(r,:)+diff60c(1,:))/2;
        end       
    end
    Zavg(g1).slice = diff60cr;
end
lower = min(min([Zavg(:).slice]));
upper = max(max([Zavg(:).slice]));

for f = 1:hrow
    g=slicepick(f, hrow, avgZrow);
    mapoverlay(Z1(1,f).slice, Zavg(1,g).slice, 0.1, lower, upper, 1, FOV);
    saveimage(save_dir,'Z',f);
    close(gcf);
end

clearvars data1 data2 hdata X1 Y1 Z1 Xdiff Ydiff Zdiff Xavg Yavg Zavg avgX avgY avgZ;
end