function mapoverlay(IM_bottom, IM_top, thresh, t_lower, t_upper, alpha, FOV)
%% COMA 3D Toolbox
%% Milton L. Truong 11-21-2013

% import image
[m, n] = size(IM_bottom);

layer = IM_top;


alpha_mask = (IM_top/t_upper);
[layer_size_x layer_size_y] = size(IM_top);
for r=1:layer_size_x;
    for c=1:layer_size_y;
       if (abs(alpha_mask(r,c))<thresh)
        alpha_mask(r,c) = 0;
       end
    end
end

mask = abs(alpha_mask);
b_lower = min(min(IM_bottom));
b_upper = max(max(IM_bottom));

% image's colormap is gray
cm1 = colormap(bone(255));
cm2 = colormap(hsv(255));

% convert bottom image to RGB values
map_gray = mat2gray(IM_bottom, [b_lower b_upper]);
map_indy = gray2ind(map_gray,255);
rgb_bottom  = ind2rgb(map_indy,cm1);

% Superimpose images
imshow(rgb_bottom, 'InitialMagnification', 'fit', 'XData', [0 FOV],...
    'YData', [0 FOV]);
hold on;
h=imagesc([0 FOV], [0 FOV], IM_top);
alpha=1;
set(h,'AlphaData',(mask).*alpha, 'CDataMapping', 'scaled')

set(gca, 'Clim',[t_lower, t_upper]);

hCBAxes = colorbar;
set(hCBAxes,'YLim',[t_lower t_upper], 'fontsize', 14);
ylabel(hCBAxes, 'Na Concentration (mM)');
 
hCBImg = findobj(hCBAxes,'type','image');
set(hCBImg,'YData',[t_lower t_upper]);
axis on;

%axis square;
mtick = FOV/6;
set(gca, 'Fontsize', 14, 'XTick', 0:mtick:FOV, 'YTick', 0:mtick:FOV);
xlabel('mm');
ylabel('mm');


end
